==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/de/lang.php <==
<?php
/**
 * german language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Andreas Gohr <andi@splitbrain.org>
 * @author     Christof <gagi@fin.de>
 * @author     Anika Henke <henke@cosmocode.de>
 * @author     Esther Brunner <esther@kaffeehaus.ch>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Diese Seite bearbeiten';
$lang['btn_source'] = 'Zeige Quelltext';
$lang['btn_show']   = 'Seite anzeigen';
$lang['btn_create'] = 'Seite anlegen';
$lang['btn_search'] = 'Suche';
$lang['btn_save']   = 'Speichern';
$lang['btn_preview']= 'Vorschau';
$lang['btn_top']    = 'Nach oben';
$lang['btn_newer']  = '<< jüngere Änderungen';
$lang['btn_older']  = 'ältere Änderungen >>';
$lang['btn_revs']   = 'Ältere Versionen';
$lang['btn_recent'] = 'Letzte Änderungen';
$lang['btn_upload'] = 'Hochladen';
$lang['btn_cancel'] = 'Abbrechen';
$lang['btn_index']  = 'Übersicht';
$lang['btn_secedit']= 'Bearbeiten';
$lang['btn_login']  = 'Anmelden';
$lang['btn_logout'] = 'Abmelden';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Updaten';
$lang['btn_delete'] = 'Löschen';
$lang['btn_back']   = 'Zurück';
$lang['btn_backlink']    = 'Links hierher';
$lang['btn_backtomedia'] = 'Zurück zur Dateiauswahl';
$lang['btn_subscribe']   = 'Änderungen abonnieren';
$lang['btn_unsubscribe'] = 'Änderungen abbestellen';

$lang['loggedinas'] = 'Angemeldet als';
$lang['user']       = 'Benutzername';
$lang['pass']       = 'Passwort';
$lang['passchk']    = 'und nochmal';
$lang['fullname']   = 'Voller Name';
$lang['email']      = 'E-Mail';
$lang['remember']   = 'Angemeldet bleiben';
$lang['register']   = 'Registrieren';
$lang['badlogin']   = 'Nutzername oder Passwort sind falsch.';

$lang['regmissing'] = 'Alle Felder müssen ausgefüllt werden';
$lang['reguexists'] = 'Der Nutzername existiert leider schon.';
$lang['regsuccess'] = 'Der neue Nutzer wurde angelegt und das Passwort per Email versandt.';
$lang['regsuccess2']= 'Der neue Nutzer wurde angelegt.';
$lang['regmailfail']= 'Offenbar ist ein Fehler beim Versenden der Passwortmail aufgetreten. Bitte wenden sie sich an den Wiki-Admin.';
$lang['regbadmail'] = 'Die angegebene Mail-Adresse scheint ungültig zu sein. Falls dies ein Fehler ist, wenden sie sich bitte an den Wiki-Admin.';
$lang['regbadpass'] = 'Die beiden eingegeben Passwörter stimmen nicht überein. Bitte versuchen Sie es noch einmal.';
$lang['regpwmail']  = 'Ihr DokuWiki Passwort';
$lang['reghere']    = 'Sie haben noch keinen Zugang? Hier anmelden';

$lang['txt_upload']   = 'Datei zum Hochladen auswählen';
$lang['txt_filename'] = 'Wikinamen eingeben (optional)';
$lang['txt_overwrt']  = 'Bestehende Datei überschreiben';
$lang['lockedby']     = 'Momentan gesperrt von';
$lang['lockexpire']   = 'Sperre läuft ab am';
$lang['willexpire']   = 'Die Sperre zur Bearbeitung dieser Seite läuft in einer Minute ab.\nUm Bearbeitungskonflikte zu vermeiden, sollten sie sie durch einen Klick auf den Vorschau-Knopf verlängern.';

$lang['notsavedyet'] = 'Nicht gespeicherte Änderungen gehen verloren!\nWeitermachen?';
$lang['rssfailed']   = 'Es ist ein Fehler beim Laden des Feeds aufgetreten: ';
$lang['nothingfound']= 'Nichts gefunden.';


$lang['mediaselect'] = 'Dateiauswahl';
$lang['fileupload']  = 'Datei hochladen';
$lang['uploadsucc']  = 'Datei wurde erfolgreich hochgeladen';
$lang['uploadfail']  = 'Hochladen fehlgeschlagen. Keine Berechtigung?';
$lang['uploadwrong'] = 'Hochladen verweigert. Diese Dateiendung ist nicht erlaubt.';
$lang['uploadexist'] = 'Datei existiert bereits. Keine Änderungen vorgenommen.';
$lang['deletesucc']  = 'Die Datei "%s" wurde gelöscht.';
$lang['deletefail']  = '"%s" konnte nicht gelöscht werden - prüfen Sie die Berechtigungen.';
$lang['mediainuse']  = 'Die Datei "%s" wurde nicht gelöscht - sie wird noch verwendet.';
$lang['namespaces']  = 'Namensräume';
$lang['mediafiles']  = 'Vorhandene Dateien in';

$lang['reference']   = 'Verwendung von';
$lang['ref_inuse']   = 'Diese Datei kann nicht gelöscht werden, da sie noch von folgenden Seiten benutzt wird:';
$lang['ref_hidden']  = 'Einige Verweise sind auf Seiten für die Sie keine Leseberechtigung haben.';

$lang['hits']       = 'Treffer';
$lang['quickhits']  = 'Passende Seitennamen';
$lang['toc']        = 'Inhaltsverzeichnis';
$lang['current']    = 'aktuell';
$lang['yours']      = 'Ihre Version';
$lang['diff']       = 'Zeige Unterschiede zu aktueller Version';
$lang['line']       = 'Zeile';
$lang['breadcrumb'] = 'Spur';
$lang['lastmod']    = 'Zuletzt geändert';
$lang['by']         = 'von';
$lang['deleted']    = 'gelöscht';
$lang['created']    = 'angelegt';
$lang['restored']   = 'alte Version wieder hergestellt';
$lang['summary']    = 'Zusammenfassung';

$lang['mail_newpage'] = 'Neue Seite:';
$lang['mail_changed'] = 'Seite geaendert:';

$lang['nosmblinks'] = 'Das Verlinken von Windows Freigaben funktioniert nur im Microsoft Internet Explorer.\nDer Link kann jedoch durch Kopieren und Einfügen verwendet werden.';

$lang['qb_alert']   = 'Bitte geben sie den zu formatierenden Text ein.\nDieser wird am Ende des Dokuments eingefügt.';
$lang['qb_bold']    = 'Fetter Text';
$lang['qb_italic']  = 'Kursiver Text';
$lang['qb_underl']  = 'Unterstrichener Text';
$lang['qb_code']    = 'Code Text';
$lang['qb_strike']  = 'Durchgestrichener Text';
$lang['qb_h1']      = 'Level 1 Überschrift';
$lang['qb_h2']      = 'Level 2 Überschrift';
$lang['qb_h3']      = 'Level 3 Überschrift';
$lang['qb_h4']      = 'Level 4 Überschrift';
$lang['qb_h5']      = 'Level 5 Überschrift';
$lang['qb_link']    = 'Interner Link';
$lang['qb_extlink'] = 'Externer Link';
$lang['qb_hr']      = 'Horizontale Linie';
$lang['qb_ol']      = 'Numerierter Listenpunkt';
$lang['qb_ul']      = 'Listenpunkt';
$lang['qb_media']   = 'Bilder und andere Dateien hinzufügen';
$lang['qb_sig']     = 'Unterschrift einfügen';

$lang['del_confirm']= 'Eintrag wirklich löschen?';

$lang['admin_acl']  = 'Zugangsverwaltung...';
$lang['admin_register']= 'Neuen Benutzer anmelden...';

$lang['acl_group']  = 'Gruppe';
$lang['acl_user']   = 'Benutzer';
$lang['acl_perms']  = 'Berechtigungen für';
$lang['page']       = 'Seite';
$lang['namespace']  = 'Namensraum';

$lang['acl_perm1']  = 'Lesen';
$lang['acl_perm2']  = 'Bearbeiten';
$lang['acl_perm4']  = 'Anlegen';
$lang['acl_perm8']  = 'Hochladen';
$lang['acl_perm16'] = 'Entfernen';
$lang['acl_new']    = 'Eintrag hinzufügen';

$lang['spell_start'] = 'Rechtschreibung prüfen';
$lang['spell_stop']  = 'Bearbeiten fortsetzen';
$lang['spell_wait']  = 'Bitte warten...';
$lang['spell_noerr'] = 'Keine Fehler gefunden';
$lang['spell_nosug'] = 'Keine Vorschläge';
$lang['spell_change']= 'Ändern';

$lang['metaedit']    = 'Metadaten bearbeiten';
$lang['metasaveerr'] = 'Die Metadaten konnten nicht gesichert werden';
$lang['metasaveok']  = 'Metadaten gesichert';
$lang['img_backto']  = 'Zurück zu';
$lang['img_title']   = 'Titel';
$lang['img_caption'] = 'Bildunterschrift';
$lang['img_date']    = 'Datum';
$lang['img_fname']   = 'Dateiname';
$lang['img_fsize']   = 'Grösse';
$lang['img_artist']  = 'Fotografin / Fotograf';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Format';
$lang['img_camera']  = 'Kamera';
$lang['img_keywords']= 'Schlagwörter';

$lang['subscribe_success']  = '%s hat nun Änderungen der Seite %s abonniert';
$lang['subscribe_error']    = '%s kann die Änderungen der Seite %s nicht abonnieren';
$lang['subscribe_noaddress']= 'Weil Deine E-Mail-Adresse fehlt, kannst Du leider das Thema nicht abonnieren';
$lang['unsubscribe_success']= 'Das Abonnement von %s für die Seite %s wurde aufgelöst';
$lang['unsubscribe_error']  = 'Das Abonnement von %s für die Seite %s konnte nicht aufgelöst werden';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/de/lang.php <==
<?php
/**
 * german language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Andreas Gohr <andi@splitbrain.org>
 * @author     Christof <gagi@fin.de>
 * @author     Anika Henke <henke@cosmocode.de>
 * @author     Esther Brunner <esther@kaffeehaus.ch>
 * @author     Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Diese Seite bearbeiten';
$lang['btn_source'] = 'Zeige Quelltext';
$lang['btn_show']   = 'Seite anzeigen';
$lang['btn_create'] = 'Seite anlegen';
$lang['btn_search'] = 'Suche';
$lang['btn_save']   = 'Speichern';
$lang['btn_preview']= 'Vorschau';
$lang['btn_top']    = 'Nach oben';
$lang['btn_newer']  = '<< jüngere Änderungen';
$lang['btn_older']  = 'ältere Änderungen >>';
$lang['btn_revs']   = 'Ältere Versionen';
$lang['btn_recent'] = 'Letzte Änderungen';
$lang['btn_upload'] = 'Hochladen';
$lang['btn_cancel'] = 'Abbrechen';
$lang['btn_index']  = 'Übersicht';
$lang['btn_secedit']= 'Bearbeiten';
$lang['btn_login']  = 'Anmelden';
$lang['btn_logout'] = 'Abmelden';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Updaten';
$lang['btn_delete'] = 'Löschen';
$lang['btn_back']   = 'Zurück';
$lang['btn_backlink']    = 'Links hierher';
$lang['btn_backtomedia'] = 'Zurück zur Dateiauswahl';
$lang['btn_subscribe']   = 'Änderungen abonnieren';
$lang['btn_unsubscribe'] = 'Änderungen abbestellen';
$lang['btn_profile']    = 'Benutzerprofil';
$lang['btn_reset']     = 'Zurücksetzen';
$lang['btn_resendpwd'] = 'Sende neues Passwort';

$lang['loggedinas'] = 'Angemeldet als';
$lang['user']       = 'Benutzername';
$lang['pass']       = 'Passwort';
$lang['newpass']    = 'Neues Passwort';
$lang['oldpass']    = 'Bestätigen (Altes Passwort)';
$lang['passchk']    = 'und nochmal';
$lang['remember']   = 'Angemeldet bleiben';
$lang['fullname']   = 'Voller Name';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registrieren';
$lang['profile']    = 'Benutzerprofil';
$lang['badlogin']   = 'Nutzername oder Passwort sind falsch.';
$lang['minoredit']  = 'kleine Änderung';

$lang['regmissing'] = 'Alle Felder müssen ausgefüllt werden';
$lang['reguexists'] = 'Der Nutzername existiert leider schon.';
$lang['regsuccess'] = 'Der neue Nutzer wurde angelegt und das Passwort per Email versandt.';
$lang['regsuccess2']= 'Der neue Nutzer wurde angelegt.';
$lang['regmailfail']= 'Offenbar ist ein Fehler beim Versenden der Passwortmail aufgetreten. Bitte wenden sie sich an den Wiki-Admin.';
$lang['regbadmail'] = 'Die angegebene Mail-Adresse scheint ungültig zu sein. Falls dies ein Fehler ist, wenden sie sich bitte an den Wiki-Admin.';
$lang['regbadpass'] = 'Die beiden eingegeben Passwörter stimmen nicht überein. Bitte versuchen Sie es noch einmal.';
$lang['regpwmail']  = 'Ihr DokuWiki Passwort';
$lang['reghere']    = 'Sie haben noch keinen Zugang? Hier anmelden';

$lang['profna']       = 'Änderung des Benutzerprofils in diesem Wiki nicht möglich.';
$lang['profnochange'] = 'Keine Änderungen, nichts zu tun.';
$lang['profnoempty']  = 'Es muß ein Name und eine E-Mail Adresse angegeben werden.';
$lang['profchanged']  = 'Benuzerprofil erfolgreich geändert.';

$lang['pwdforget']    = 'Passwort vergessen? Kein Problem';
$lang['resendna']      = 'Passwörter versenden ist in diesem Wiki nicht möglich.';
$lang['resendpwd']      = 'Neues Passwort schicken für';
$lang['resendpwdmissing'] = 'Es tut mir Leid, aber Sie müssen alle Felder ausfüllen.';
$lang['resendpwdnouser']  = 'Es tut mir Leid, aber der Benutzer existiert nicht in unserer Datenbank.';
$lang['resendpwdsuccess'] = 'Ihr neues Passwort wurde per E-Mail versandt.';

$lang['txt_upload']   = 'Datei zum Hochladen auswählen';
$lang['txt_filename'] = 'Wikinamen eingeben (optional)';
$lang['txt_overwrt']  = 'Bestehende Datei überschreiben';
$lang['lockedby']     = 'Momentan gesperrt von';
$lang['lockexpire']   = 'Sperre läuft ab am';
$lang['willexpire']   = 'Die Sperre zur Bearbeitung dieser Seite läuft in einer Minute ab.\nUm Bearbeitungskonflikte zu vermeiden, sollten Sie sie durch einen Klick auf den Vorschau-Knopf verlängern.';

$lang['notsavedyet'] = 'Nicht gespeicherte Änderungen gehen verloren!\nWeitermachen?';
$lang['rssfailed']   = 'Es ist ein Fehler beim Laden des Feeds aufgetreten: ';
$lang['nothingfound']= 'Nichts gefunden.';

$lang['mediaselect'] = 'Dateiauswahl';
$lang['fileupload']  = 'Datei hochladen';
$lang['uploadsucc']  = 'Datei wurde erfolgreich hochgeladen';
$lang['uploadfail']  = 'Hochladen fehlgeschlagen. Keine Berechtigung?';
$lang['uploadwrong'] = 'Hochladen verweigert. Diese Dateiendung ist nicht erlaubt.';
$lang['uploadexist'] = 'Datei existiert bereits. Keine Änderungen vorgenommen.';
$lang['deletesucc']  = 'Die Datei "%s" wurde gelöscht.';
$lang['deletefail']  = '"%s" konnte nicht gelöscht werden - prüfen Sie die Berechtigungen.';
$lang['mediainuse']  = 'Die Datei "%s" wurde nicht gelöscht - sie wird noch verwendet.';
$lang['namespaces']  = 'Namensräume';
$lang['mediafiles']  = 'Vorhandene Dateien in';

$lang['reference']   = 'Verwendung von';
$lang['ref_inuse']   = 'Diese Datei kann nicht gelöscht werden, da sie noch von folgenden Seiten benutzt wird:';
$lang['ref_hidden']  = 'Einige Verweise sind auf Seiten, für die Sie keine Leseberechtigung haben.';

$lang['hits']       = 'Treffer';
$lang['quickhits']  = 'Passende Seitennamen';
$lang['toc']        = 'Inhaltsverzeichnis';
$lang['current']    = 'aktuell';
$lang['yours']      = 'Ihre Version';
$lang['diff']       = 'Zeige Unterschiede zu aktueller Version';
$lang['line']       = 'Zeile';
$lang['breadcrumb'] = 'Spur';
$lang['youarehere'] = 'Sie befinden sich hier';
$lang['lastmod']    = 'Zuletzt geändert';
$lang['by']         = 'von';
$lang['deleted']    = 'gelöscht';
$lang['created']    = 'angelegt';
$lang['restored']   = 'alte Version wieder hergestellt';
$lang['summary']    = 'Zusammenfassung';

$lang['mail_newpage'] = 'Neue Seite:';
$lang['mail_changed'] = 'Seite geaendert:';

$lang['nosmblinks'] = 'Das Verlinken von Windows Freigaben funktioniert nur im Microsoft Internet Explorer.\nDer Link kann jedoch durch Kopieren und Einfügen verwendet werden.';

$lang['qb_alert']   = 'Bitte geben sie den zu formatierenden Text ein.\nDieser wird am Ende des Dokuments eingefügt.';
$lang['qb_bold']    = 'Fetter Text';
$lang['qb_italic']  = 'Kursiver Text';
$lang['qb_underl']  = 'Unterstrichener Text';
$lang['qb_code']    = 'Code Text';
$lang['qb_strike']  = 'Durchgestrichener Text';
$lang['qb_h1']      = 'Level 1 Überschrift';
$lang['qb_h2']      = 'Level 2 Überschrift';
$lang['qb_h3']      = 'Level 3 Überschrift';
$lang['qb_h4']      = 'Level 4 Überschrift';
$lang['qb_h5']      = 'Level 5 Überschrift';
$lang['qb_link']    = 'Interner Link';
$lang['qb_extlink'] = 'Externer Link';
$lang['qb_hr']      = 'Horizontale Linie';
$lang['qb_ol']      = 'Numerierter Listenpunkt';
$lang['qb_ul']      = 'Listenpunkt';
$lang['qb_media']   = 'Bilder und andere Dateien hinzufügen';
$lang['qb_sig']     = 'Unterschrift einfügen';
$lang['qb_smileys'] = 'Smileys';
$lang['qb_chars']   = 'Sonderzeichen';

$lang['del_confirm']= 'Eintrag wirklich löschen?';
$lang['admin_register']= 'Neuen Benutzer anmelden';

$lang['spell_start'] = 'Rechtschreibung prüfen';
$lang['spell_stop']  = 'Bearbeiten fortsetzen';
$lang['spell_wait']  = 'Bitte warten...';
$lang['spell_noerr'] = 'Keine Fehler gefunden';
$lang['spell_nosug'] = 'Keine Vorschläge';
$lang['spell_change']= 'Ändern';

$lang['metaedit']    = 'Metadaten bearbeiten';
$lang['metasaveerr'] = 'Die Metadaten konnten nicht gesichert werden';
$lang['metasaveok']  = 'Metadaten gesichert';
$lang['img_backto']  = 'Zurück zu';
$lang['img_title']   = 'Titel';
$lang['img_caption'] = 'Bildunterschrift';
$lang['img_date']    = 'Datum';
$lang['img_fname']   = 'Dateiname';
$lang['img_fsize']   = 'Grösse';
$lang['img_artist']  = 'FotografIn';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Format';
$lang['img_camera']  = 'Kamera';
$lang['img_keywords']= 'Schlagwörter';

$lang['subscribe_success']  = '%s hat nun Änderungen der Seite %s abonniert';
$lang['subscribe_error']    = '%s kann die Änderungen der Seite %s nicht abonnieren';
$lang['subscribe_noaddress']= 'Weil Deine E-Mail-Adresse fehlt, kannst Du leider das Thema nicht abonnieren';
$lang['unsubscribe_success']= 'Das Abonnement von %s für die Seite %s wurde aufgelöst';
$lang['unsubscribe_error']  = 'Das Abonnement von %s für die Seite %s konnte nicht aufgelöst werden';

/* auth.class lanuage support */
$lang['authmodfailed']   = 'Benutzerüberprüfung nicht möglich. Bitte wenden Sie sich an den Systembetreuer.';
$lang['authtempfail']    = 'Benutzerüberprüfung momentan nicht möglich. Falls das Problem andauert wenden Sie sich an den Systembetreuer.';

//Setup VIM: ex: et ts=2 enc=utf-8 :
